@@ -10,8 +10,7 @@ from boto.ec2.connection import EC2Connection
 from boto.ec2.regioninfo import RegionInfo
 import boto.ec2
 
-import bliss.saga as saga
-import bliss
+import saga
 
 ###############################################################################
 # EC2 General
@@ -168,26 +167,33 @@ class Job(object):
         self.network_ip = self.instance.ip_address 
         url = "ssh://" + str(self.network_ip)
         logger.debug("Connect to: %s"%(url))
-        js = saga.job.Service(url)
+
         
         # Submit job
-        ctx = saga.Context()
-        ctx.type = saga.Context.SSH
-        ctx.userid = self.pilot_compute_description["vm_ssh_username"]
-        ctx.userkey = self.pilot_compute_description["vm_ssh_keyfile"]
-        js.session.contexts = [ctx]
+        ctx = saga.Context("SSH")
+        #ctx.type = saga.Context.SSH
+        ctx.user_id = self.pilot_compute_description["vm_ssh_username"]
+        ctx.user_key = self.pilot_compute_description["vm_ssh_keyfile"]
 
-        logger.debug("Job Description Type: " + str(type(self.job_description)))
-
-        job = js.create_job(self.job_description)
-        
+        session = saga.Session()
+        session.add_context(ctx)
+                
         TRIAL_MAX=30
         trials=0
         while trials < TRIAL_MAX:
             try:
+                js = saga.job.Service(url, session=session)
+                logger.debug("Job Description Type: " + str(type(self.job_description)))
+                job = js.create_job(self.job_description)
                 logger.debug("Attempt: %d, submit pilot job to: %s "%(trials,str(url)))
                 job.run()
-                break
+                if job.get_state()==saga.job.FAILED:
+                    logger.warning("Submission failed.")
+                    trials = trials + 1 
+                    time.sleep(30)
+                    continue
+                else:
+                    break
             except:
                 exc_type, exc_value, exc_traceback = sys.exc_info()
                 logger.warning("Submission failed: " + str(exc_value))
